@@ -7,11 +7,11 @@ def sql_lint(sql):
             return
 
     # Check whether a python string template wasn't filled
-    assert '{' not in sql
-    assert '}' not in sql
+    assert "{" not in sql
+    assert "}" not in sql
 
     # Check for balanced parentheses
-    assert sql.count('(') == sql.count(')')
+    assert sql.count("(") == sql.count(")")
 
     # Check for balanced quote marks
     assert sql.count("'") % 2 == 0
